function [LorentzCorrection,varargout] = Lorentz(R,TWOTHETA, SAXSstop, Radius, RadiusUnit, ~)

    UseGPU = true;
    
    switch RadiusUnit 
        case 'pixels'
            RadiusIndicator = R;
        case 'degrees'
            RadiusIndicator = TWOTHETA;
            Radius.min = Radius.min/180*pi;
            SAXSstop = SAXSstop/180*pi;
    end    
    isSAXS = RadiusIndicator < max(SAXSstop,Radius.min);
    isWAXS = ~isSAXS; % Faster to only do this once!
	LorentzCorrection = 1./(2.*sin(TWOTHETA./2));

    try
	allMEAN = mean(mean(LorentzCorrection(isWAXS),'omitnan'),'omitnan');
	
    catch
	    try
		allMEAN = mean(mean(LorentzCorrection(isWAXS),'omitnan'),'omitnan');
	    catch
		allMEAN = mean(LorentzCorrection(isWAXS),'all','omitnan');
	    end
    end
    if nargout == 1
        LorentzCorrection = LorentzCorrection./allMEAN;    
    else
        varargout{1} = [numel(LorentzCorrection(isWAXS)),allMEAN];
    end
    LorentzCorrection(isSAXS) = 1;  
    if isa(LorentzCorrection,'gpuArray')
        LorentzCorrection = gather(LorentzCorrection);
    end
end