function [MaskCorrection, MaskCorrectionIntegrated] = Mask(binIndices,pixIndices,mask,threshold,Radius,Azi)
    %% NANCORRECTIONS/MASKCORRECTIONS (version 2):
    % This NaN-correction should simply be multiplied on the
    % unfolded image.
    % Use of nested function here:
    % MASK IS HERE THE NUMBER OF MASKED OUT PIXELS (i.e. NOT INCLUDED PIXELS)
    
    % Make a transformation matrix for unfolding/integration of ones. 
    TRANSMAT = MatFRAIA.subfunctions.sparseInSteps(binIndices,pixIndices,1,[Radius.N*Azi.N,numel(mask)],4,false);
    
    UnfoldMask = reshape(TRANSMAT*double(~mask(:)),[Radius.N, Azi.N]);

    IM = ones(size(mask(:)));
    UnfoldOnes = reshape(TRANSMAT*IM,[Radius.N, Azi.N]);
    ratio = UnfoldMask./UnfoldOnes;
    removeThese = ratio > threshold;
    
    MaskCorrectionIntegrated = UnfoldOnes./(UnfoldOnes-UnfoldMask);
    MaskCorrectionIntegrated(removeThese) = NaN;
    
    % Find i-indices (bin-indices), and adjust weights of pixels into
        % the bins.
        [i,j,~] = find(TRANSMAT);
        v = MaskCorrectionIntegrated(i);
        MaskCorrection = sparse(i,j,v, Radius.N*Azi.N,numel(mask));
                
    %% PROOF:
    %{
                figure;plot(UnfoldMask); title('Masked out (removed) number of pixels in bin')
                figure;plot(UnfoldOnes); title('Total number of pixels in bin')
                unfMask = NESTEDUNFOLDING_MASK(double(mask(:)),UnfVectorSparse,Radius.N,Azi.N);
                figure;plot(unfMask); title({'Unfolded corrected mask','Corrected number of pixels in bin'})
                figure;plot(UnfoldOnes./unfMask); title({'Unfolded NO. pixels in bin / Unfolded corrected mask','Number of (corrected) pixels in bin'})
    %}
end