function PolarizationCorrection = Polarization(TWOTHETA,phi,PolCorrFactor,n)

    
    % ----------------- CREDIT -------------------------
    % Polarization Correction function based on "Uses of Synchrotron Radiation
    % in Chemical Crystallography - Th�se de doctorat" by Henrik Birkedal,
    % 2000, Universit� de Lausanne.
    
    % -------------- INFO ----------------
    % - 'X' should be oriented such that the change in X is in the horizontal
    % physical/scattering plane (primarily), when PolCorrFactor is
    % positive.
    % - 'sample2detectorDistance' should have same units as 'X' and 'yscaled'
    % - n = 1 for a perfect (dynamic) crystal at phi = 90 deg. or:
    % n = 2 for an ideally imperfect (kinematic) crystal at phi = 90 deg.
    
    %phi =@(x,y) atan(y./x); % Azimuthal angle (in rad) to a given pixel position
    %tth =@(x,y,s2d) atan(sqrt(x.^2+y.^2)./s2d); % tth = two theta (in rad)
    %P0 =@(x,y,s2d,n) 1/2.*(1+abs(cos(tth(x,y,s2d)).^n)); 
    %alpha =@(x,y,s2d,n) cos(2.*phi(x,y)).*((1-abs(cos(tth(x,y,s2d)).^n))./(1+abs(cos(tth(x,y,s2d)).^n)));
    %P = P0*(1-alpha*PolCorrFactor)

    if mod(n,2)
        %TWOTHETA = atan(R./samp2det); % tth = two theta (in rad)
        K = abs(cos(TWOTHETA).^n);
    else
        K = cos(TWOTHETA).^n;
    end
    
    %P0 = 1/2.*(1+K); 
    %phi = atan(y./x); % Azimuthal angle (in rad) to a given pixel position
    %%alpha = cos(2.*phi).*((1-K)./(1+K));
    %alpha = cos(2.*phi).*((1-K)./(P0*2));
    %PolarizationCorrection = P0.*(1-alpha.*PolCorrFactor);
    PolarizationCorrection = 1/2.*(1+K).*(1-cos(2.*phi).*((1-K)./(1+K)).*PolCorrFactor);
end