function [x, y] = Tilt(x, y, tiltRotation, tiltDelta, sample2detector)
	% Detector tilt correction
	% [x, y] = Tilt(x, y, tiltRotation, tiltDelta, sample2detector),
	% INPUT
	% x_coord DOUBLE(Ncols); x coordinates on the tilted detector in pixels.
	% The beam center is at x=0.
	% y_coord DOUBLE(Nrows); y coordinates on the tilted detector in pixels.
	% The beam center is at y=0.
	% tiltRotation DOUBLE(1); angle between x- and rotation-axes [deg].
	% tiltDelta DOUBLE(1); detector tilt angle [deg].
	% sample2detector DOUBLE(1); sample to detector distance [pixels].
	% OUTPUT
	% x: x coordinates on the untilted detector [pixels].
	% y: y coordinates on the untilted detector [pixels].
	
	% EXPLANATION!!!!!!
	% tiltRotation: is the rotation around the normal to the detector, and
	% tiltDelta is how much the normal to the detector diviates from
	% the beam vector (or rather the anti-parallel beam vector), i.e. if
	% given vector in the detector plane is perpenducular to the
	% incident beam vector: tiltDelta = 0, thus tiltRotation should also be 0.
	
	tiltRotation = (tiltRotation + 90) * pi/180;
	tiltDelta = tiltDelta * pi/180;
	
	% calculate points on tilted detector in untilted coordinates.
	
	e = cos(tiltRotation)^2+sin(tiltRotation)^2*cos(tiltDelta);
	g = sin(tiltRotation)*cos(tiltRotation)*(1-cos(tiltDelta));
	xx = e*x + g*y;
	e = g;
% 	e = sin(tiltRotation)*cos(tiltRotation)*(1-cos(tiltDelta));
	g = sin(tiltRotation)^2+cos(tiltRotation)^2*cos(tiltDelta);
	yy = e*x + g*y;
	e = -sin(tiltRotation)*sin(tiltDelta);
	g = cos(tiltRotation)*sin(tiltDelta);
	zz = e*x + g*y;
	
	% projection of points on tilted detector onto untilted detector.
	zz = 1 + zz/sample2detector;
	x = xx.*zz;
	y = yy.*zz;
	
	% Inspired by a function written by Ulrich Lienert, which was a 
	% variation (for speed and compatibility) of a function written
	% originally by David Beer as a summer intern at Argonne
	% National Labs in 2003.
end