function [IntIdxAdjusted, ADJUSTMENTS]= adjustMaskCorrection(INTIDXWithNoPreviousMaskCorrections,MaskCorrectionThreshold,~,newmask,useGPU)

	INTIDXWithNoPreviousMaskCorrections.TRANSMAT = gather(INTIDXWithNoPreviousMaskCorrections.TRANSMAT);
        INTONES     = MatFRAIA.integrate(INTIDXWithNoPreviousMaskCorrections, ones(numel(newmask),1) );
        INTNEWMASK  = MatFRAIA.integrate(INTIDXWithNoPreviousMaskCorrections, reshape(~newmask,[numel(newmask), 1]) );

	ADJUSTMENTS = INTONES./(INTONES-INTNEWMASK);
        ADJUSTMENTS(isnan(ADJUSTMENTS) | (ADJUSTMENTS == Inf)) = 0;
	
        % Set all ADJUSTMENTS to bins above the set threshold to 0
        % (non-contributing):
        rmTHESE = (INTNEWMASK./INTONES) > MaskCorrectionThreshold;
        
        ADJUSTMENTS(rmTHESE) = nan; 
        
        [i,j,v] = find(INTIDXWithNoPreviousMaskCorrections.TRANSMAT);
        % Remove all but the first ADJUSTMENTS(i) that is nan (for
        % unique i's), i.e. i = [1,1,1,1,2,3,4,5,5,5], will become: 
        % i = [1, 2,3,4,5,5,5] if ADJUSTMENT(1) is nan.
        % Keep only the first bin index (i), if it points to a bin that is
        % ultimately nan'ed, since no pixels (j) that points into a bin 
        % that is eventually nan'ed will be a waste of computation time.
        
        [~,ia] = unique(i,'first'); 
        firstNan = isnan(ADJUSTMENTS(i(ia)));
        
        shouldBeNan = ia(firstNan);
        allNans =  isnan(ADJUSTMENTS(i));
        allNans(shouldBeNan) = false;  
        i(allNans) = [];
        v(allNans) = [];
        j(allNans) = [];
        % ADJUSTMENT is applied and remove all the contribution from masked
        % out pixels:
        v = v.*ADJUSTMENTS(i).*newmask(j);
        IntIdxAdjusted.RadiusN = INTIDXWithNoPreviousMaskCorrections.RadiusN;
        IntIdxAdjusted.AziN = INTIDXWithNoPreviousMaskCorrections.AziN;
        IntIdxAdjusted.TRANSMAT = gather(MatFRAIA.subfunctions.sparseInSteps(i,j,v,size(INTIDXWithNoPreviousMaskCorrections.TRANSMAT),useGPU));
        
end  