function [INPUTVARS, EXPERIMENT_INFO]= performChecksAndInfo(inputnames,mask,EXPERIMENT_INFO,INTEGRATION_OPTIONS,INPUTS,INPUTVARS,NOinputs4indexing)
	
	% Define marker indicators in the print-out info:
		
	indicators = struct('user','o','default',' ');
	keyExplaination = sprintf('("%s" = user-defined, "%s" = default)',indicators.user,indicators.default);
	threshold = INPUTVARS.MaskCorrectionThreshold;
	
	% Check if RADIUS struct is fine:
	if strcmp(INPUTVARS.RadiusUnit,'pixels') && strcmp(INPUTVARS.ConstantSpacingIn,'pixels')
		EXPERIMENT_INFO.detector.distance = NaN;
		tmpRadius = MatFRAIA.subfunctions.calculateRadiusBoundaries(EXPERIMENT_INFO.center,[],[],size(mask),INPUTVARS.RadiusUnit);
    elseif (isempty(INPUTVARS.Radius)) || (~isfield(INPUTVARS.Radius,'min') || isempty(INPUTVARS.Radius.min)) || (~isfield(INPUTVARS.Radius,'max') || isempty(INPUTVARS.Radius.max))
        tmpRadius = MatFRAIA.subfunctions.calculateRadiusBoundaries(EXPERIMENT_INFO.center,EXPERIMENT_INFO.detector.distance,EXPERIMENT_INFO.detector.pixsize,size(mask),INPUTVARS.RadiusUnit);
	end
	if isempty(INPUTVARS.Radius)
		INPUTVARS.Radius = tmpRadius;
	end
	if ~isfield(INPUTVARS.Radius,'min') || isempty(INPUTVARS.Radius.min)
		INPUTVARS.Radius.min = tmpRadius.min;
% 		INPUTVARS.Radius.max = tmpRadius.max;
	end
	if ~isfield(INPUTVARS.Radius,'max') || isempty(INPUTVARS.Radius.max)
% 		INPUTVARS.Radius.min = tmpRadius.min;
		INPUTVARS.Radius.max = tmpRadius.max;
	end
	% END OF: "Check if RADIUS struct is fine"
	
	Radius	= INPUTVARS.Radius;
	Azi	= INPUTVARS.Azi;
	scaling	= INPUTVARS.Scaling;
	
	if INPUTVARS.doMaskCorrection
		assert(~isempty(threshold),"a non-empty 'MaskCorrectionThreshold' field is required in the '%s'-struct, please provide this.",inputnames{3})
	end
	if any(isnan(mask))
		error('Mask input contain NaNs, the input mask should preferably be a logical matrix containing 0/false (masked out) and 1/true (kept values).')
	end
	if all(mask == 0)
		error('Mask input only contain zeros/false, the input mask should preferably be a logical matrix containing 0/false (masked out) and 1/true (kept values).')
	end
	assert(NOinputs4indexing == 3,'Incorrect number of input arguments (%g was provided, but at least 3 are required)',NOinputs4indexing)
	assert(isstruct(EXPERIMENT_INFO),'Incorrect inputtype for input no. 2, (input variable is named: "%s" in the function call), the type was "%s" but should be struct.',inputnames{2},class(EXPERIMENT_INFO))
	assert(isstruct(INTEGRATION_OPTIONS),'Incorrect inputtype for input no. 3, (input variable is named: "%s" in the function call), the type was "%s" but should be struct.',inputnames{2},class(INTEGRATION_OPTIONS))
	% CHECK EX STRUCT:
	if ~INPUTVARS.SuppressTiltCheck && INPUTVARS.doTiltCorrection
		if isfield(EXPERIMENT_INFO,'tilt')
			if isfield(EXPERIMENT_INFO.tilt,'delta') && isfield(EXPERIMENT_INFO.tilt,'rot')
				assert(0 <= EXPERIMENT_INFO.tilt.delta, 'The angle for in-plane rotation of detector coordinates (the EX.tilt.delta = %g) is not within 0 <= angle[deg.] <= 180, as it should be.',EXPERIMENT_INFO.tilt.delta)
			else
				error('EXPERIMENT_INFO.tilt struct is missing "delta" or "rot" field. Please either set name-pair value "SuppressTiltCheck" to true, or defile EXPERIMENT_INFO.tilt.delta and EXPERIMENT_INFO.tilt.rot.')
			end
		else
			error('EX struct is missing "tilt"-field. Please either set name-pair value "SuppressTiltCheck" to true, or defile EXPERIMENT_INFO.tilt.delta and EXPERIMENT_INFO.tilt.rot.')
		end
	end
	
	% CHECK Radius and Azi STRUCT:
	checkRadiusAndAziStruct(Radius,Azi)
	
	% If RadiusUnit is set to pixels and SAXSstop is default, then the default are recalculated into a radius in units of pixels.
	if strcmp(INPUTVARS.RadiusUnit,'pixels') && any(strcmp('LorentzCorrectionStartRadius',INPUTS.UsingDefaults))
		if isfield(INPUTVARS,'detector') && (~isempty(INPUTVARS.detector.distance) || ~INPUTVARS.detector.distance)
			INPUTVARS.LorentzCorrectionStartRadius = tand(INPUTVARS.LorentzCorrectionStartRadius)*EXPERIMENT_INFO.detector.distance/EXPERIMENT_INFO.detector.pixsize;
		else
			INPUTVARS.LorentzCorrectionStartRadius = 0;
		end
	end
	if Radius.min > INPUTVARS.LorentzCorrectionStartRadius
		fprintf('ATTENTION: Radius.min < LorentzCorrectionStartRadius (in units of %s), i.e. (%g < %g). This means that the signal of the pixels in the range of %g <= distance < %g from center will NOT be Lorentz corrected, while %g <= distance < %g will.\n',...
			INPUTVARS.RadiusUnit,Radius.min,INPUTVARS.LorentzCorrectionStartRadius,Radius.min,INPUTVARS.LorentzCorrectionStartRadius, INPUTVARS.LorentzCorrectionStartRadius, Radius.max)
	end
	
	changedGPUstate = false;
	if INPUTVARS.UseGPU; try gpuArray(1); catch; INPUTVARS.UseGPU = false; changedGPUstate = true;end;end
	if INPUTVARS.PrintInfo
		UsingDefault =@(param) ismember(param,INPUTS.UsingDefaults);
		% Replace true/false with blank/*-marking, indicating
		% whether default setting was used (blank) or not (*).
		trueFalse2Default =@(paramName,param) [regexprep(num2str(UsingDefault(param)),{'0','1'},{[indicators.user,' '],[indicators.default,' ']}) , paramName];
		trueFalse2DisabledEnabled = @(str) regexprep(num2str(str),{'0','1'},{'DISABLED','ENABLED'});
		useGPUstr = trueFalse2DisabledEnabled(INPUTVARS.UseGPU);
		strLength = '20';
		preString  = ['   %-',strLength,'s'];
		preString2 = ['   %1$-',strLength,'s'];
		fprintf('%s - Running: Indexing for unfolding:\n',datestr(now,13))
		
		fprintf(['------- SETTINGS --------',keyExplaination,'\n'])
		
		% USE GPU
		fprintf([preString,' %s%s'],'Use GPU:',trueFalse2Default('','UseGPU'),useGPUstr)
		if changedGPUstate; fprintf('(DISABLED Could not use GPU for indexing, using CPU instead. Perhaps due to insufficient memory on GPU, or incompatible GPU (try gpuDevice in command window to see if GPU is available))');end;fprintf('\n')
		% SCALING
		if scaling == 1
			fprintf([preString,' 1 (Pixels are NOT split into subpixels)\n'],'Scaling:',trueFalse2Default('','Scaling'))
		else
			fprintf([preString2,' %3$s%2$d (splits each pixel into %2$d x %2$d subpixels)\n'],'Scaling:',scaling,trueFalse2Default('','Scaling'))
		end 
		% RADIUS
		fprintf([preString,' %sMIN: %g, MAX: %g, Number of bins: %d\n'],sprintf('Radius [%s]',INPUTVARS.RadiusUnit), trueFalse2Default('','Radius'), Radius.min,Radius.max,Radius.N)
		% AZI
		fprintf([preString,' %sMIN: %g pi, MAX: %g pi, Number of bins: %d%s\n'],'Azimuthal [rad]:',trueFalse2Default('','Azi'),Azi.min/pi,Azi.max/pi,Azi.N,sprintf(', cart. coord. system rotation: %g pi',INPUTVARS.ShiftAzi/pi))
		% CONSTANTSPACINGIN / Integration space
		fprintf([preString,' %s%s (The unit in which the resulting bins are equidistant)\n'],'Integrating to:',trueFalse2Default('','ConstantSpacingIn'),INPUTVARS.ConstantSpacingIn)
		% CENTER:
		fprintf([preString,' %s(%g,%g) = (vertical,horizontal), i.e.: (rows,cols)\n'],'Det. center [pix]:',trueFalse2Default('','center'),EXPERIMENT_INFO.center.y,EXPERIMENT_INFO.center.x)
		% DETECTOR DISTANCE
		fprintf([preString,' %s%g\n'],'Det. distance [mm]:',trueFalse2Default('','detector'),EXPERIMENT_INFO.detector.distance)
		% E.g.: for first pixel with edges: [0 1] in x, and [0 1] in y, has a center
		% (non-scaled) in (0.5, 0.5), scaled to 10 x 10 subpixels (scaling
		% 10), the first center should now be in (0.05,0.05), due to edges at
		% [0 0.1] in x and likewise in y.
		% The next (in incremented x direction):
		% edges: x = [0.1, 0.2], y = [0 0.1]
		% center: (x,y) = (0.05+1/scaling, 0.05) = (0.15, 0.05)
		% or alternatively:
		% center: (x,y) = ((0.2-0.1)/2+1/scaling, (0.1-0)/2) = (0.15, 0.05)
		% Hence the general expression (for 1st pixel):
		% center: (x,y) = linspace(0+1/(2*scaling),1-1/(2*scaling),1*scaling);
		% And the general expression for all pixels are then as seen above.
		%if scaling > 1
		%	fprintf('   First (index) subpixel center coordinate: (%g,%g) = (y,x)\n',idxRowsY(1),idxColsX(1))
		%else
		%	fprintf('   First (index) pixel center coordinate: (%g,%g) = (y,x)\n',idxRowsY(1),idxColsX(1))
		%end
% 		trueFalse2Default =@(paramName,param) [regexprep(num2str(UsingDefault(param)),{'0','1'},{'*','^'}), paramName];
		fprintf(['------- CORRECTIONS -------- ',keyExplaination,'\n'])
		% MASK
		fprintf([preString,' %-8s (Pct. masked out: %2.2f %%, Threshold: %g, if the percentage of masked-out-pixels (in a bin) exceeds %g pct., the entire bin is set to nan, if not, it is corrected for)\n'],'Mask:',trueFalse2Default(trueFalse2DisabledEnabled(INPUTVARS.doMaskCorrection),'doMaskCorrection'),(1-nnz(mask)./numel(mask))*100,threshold,threshold*100)
		% TILT
		tiltString = trueFalse2Default(trueFalse2DisabledEnabled(INPUTVARS.doTiltCorrection),'doTiltCorrection');
		if INPUTVARS.doTiltCorrection
			if ~EXPERIMENT_INFO.tilt.rot && ~EXPERIMENT_INFO.tilt.delta
				INPUTVARS.doTiltCorrection = false;
				fprintf([preString,' %-8s (due to: Tilt rotation: %g, Tilt delta: %g)\n'],'Detector tilt:',tiltString,EXPERIMENT_INFO.tilt.rot,EXPERIMENT_INFO.tilt.delta)
			else
				fprintf([preString,' %-8s (Tilt rotation: %g, Tilt delta: %g)\n'],'Detector tilt:',tiltString,EXPERIMENT_INFO.tilt.rot,EXPERIMENT_INFO.tilt.delta)
			end
		else
			fprintf([preString,' %-8s\n'],'Detector tilt:',tiltString)
		end
		% POLARIZATION
		chosenCrystalStr = regexprep("" + INPUTVARS.PolarizationFactors(2) + " at phi = 90 deg.",{'1','2'},{'perfect (dynamic) crystal','imperfect (kinematic) crystal'});
		fprintf([preString,' %-8s (Pol. factor: %g, n = %g i.e. %s)\n'],'Polarization:',trueFalse2Default(trueFalse2DisabledEnabled(INPUTVARS.doPolarizationCorrection),'doPolarizationCorrection'),INPUTVARS.PolarizationFactors(1),INPUTVARS.PolarizationFactors(2), chosenCrystalStr)
		% LORENTZ
		fprintf([preString,' %-8s (Start of Lorentz correction, aka. the end of SAXS region: %g %s)\n'],'Lorentz:',trueFalse2Default(trueFalse2DisabledEnabled(INPUTVARS.doLorentzCorrection),'doLorentzCorrection'),INPUTVARS.LorentzCorrectionStartRadius,INPUTVARS.RadiusUnit)
		% SOLID ANGLE
		fprintf([preString,' %-8s (should ONLY be ENABLED if constant pixel spacing was chosen)\n'],'Solid Angle:',trueFalse2Default(trueFalse2DisabledEnabled(INPUTVARS.doSolidAngleCorrection),'doSolidAngleCorrection'))
		if ~INPUTVARS.doSolidAngleCorrection && strcmp(INPUTVARS.ConstantSpacingIn,'pixels')
			for NOwarnings = 1:3; fprintf("! N.B.: due to constant spacing set to pixels, the setting for doSolidAngleCorrection should be ENABLED (set to TRUE)!\n"); end
		end
		% OUT-OF-DETECTOR
		fprintf([preString,' %-8s (Compensate for incomplete Debye-Scherrer rings)\n'],'Out-of-detector:',trueFalse2Default(trueFalse2DisabledEnabled(INPUTVARS.doOutOfDetectorCorrection),'doOutOfDetectorCorrection'))
		% NORMALIZATION
		
		fprintf([preString,' %-8s\n'],'Normalization:',trueFalse2Default(INPUTVARS.NormalizationMethod,'NormalizationMethod'))
		% DEBUGGING MODE
		if INPUTVARS.Debugging; fprintf([preString,' %-8s\n'],'Debugging MODE:',trueFalse2DisabledEnabled(INPUTVARS.Debugging));end
	end
	% MATLAB VERSION 
	INPUTVARS.MATLABversionYear = str2double(regexp(version(),'(?<=R)\d{4}','match','once'));
	sprintf('');
	
end

function checkRadiusAndAziStruct(Radius,Azi)
	ErrorsFromMissingFields = 0;
	for ij = 1:2
		if ij == 1
			RadAzi = Radius;
			What = 'Radius';
		else	
			RadAzi = Azi;
			What = 'Azi';
		end
		requiredfields = {'min','max','N'};
		if ~all(isfield(RadAzi,requiredfields))
			missingfields = requiredfields(~isfield(RadAzi,requiredfields));
			fprintf(['"',What,'"-struct is missing the following fields: ']);
			for ii = 1:numel(missingfields)-1; fprintf('"%s", ',missingfields{ii});end;fprintf('"%s".\n',missingfields{end});
			ErrorsFromMissingFields = ErrorsFromMissingFields + numel(missingfields);
		end
	end
	assert(ErrorsFromMissingFields == 0,'A total of %d field(s) where missing from the struct(s) indicated above.',ErrorsFromMissingFields);
end

function arr = getAllFieldsInArray(structure)
	arr = [];
	allFields = fields(structure);
	for field = allFields.'
		if isstruct(structure.(field))
			arr = [arr,getAllFieldsInArray(structure.(field))];
		else
			arr = [arr,structure.(field)];
		end
	end
end


function out = getVarName(var)
    out = inputname(1);
end