function INPUTVARS = performChecksAndInfo2(inputnames,mask,EXPERIMENT_INFO,INTEGRATION_OPTIONS,INPUTS,INPUTVARS,NOinputs4indexing)
	
	% Create a struct where the fieldname contains the string to be
	% used for printing. One for EXPERIMENT_INFO and one for
	% INTEGRATION_OPTIONS.
	
	
	ERRORFCN()
	
	preString = '[%s]%-20s';
	trueFalseStrConv = @(str) regexprep(num2str(str),{'0','1'},{'DISABLED','ENABLED'});
	
	for fld = fields(EXPERIMENT_INFO.manuallySet).'
		fld
		switch fld{1}
			case 'Scaling'
				if scaling == 1
					STRINGS.(fld{1}) = 'Scaling: 1 (Pixels are NOT split into subpixels)';
				else;		 
					STRINGS.(fld{1}) = sprintf('Scaling: %1$d (splits each pixel into %1$d x %1$d subpixels)',scaling); 
				end
			case 'UseGPU'
				changedGPUstate = false;
				if INPUTVARS.UseGPU
					try gpuArray(1); 
					catch; INPUTVARS.UseGPU = false; changedGPUstate = true;
					end
				end
				STRINGS.(fld{1}) = ['Use GPU: ', trueFalseStrConv(INPUTVARS.UseGPU)];
				if changedGPUstate
					STRINGS.(fld{1}) = [STRINGS.(fld{1}), ' (DISABLED Could not use GPU for indexing, using CPU instead. Perhaps due to insufficient memory on GPU, or incompatible GPU (try gpuDevice in command window to see if GPU is available))'];
				end
			case 'Radius'
				STRINGS.(fld{1}) = sprintf('Radius [%s]: MIN: %g, MAX: %g, Number of bins: %d',INPUTVARS.RadiusUnit,INPUTVARS.Radius.min,INPUTVARS.Radius.max,INPUTVARS.Radius.N);
			case 'Azi'
				STRINGS.(fld{1}) = sprintf('Azi [rad]: MIN: %g, MAX: %g, Number of bins: %d, cart. coord. system rotation: %g pi',INPUTVARS.Azi.min/pi,INPUTVARS.Azi.max/pi,INPUTVARS.Azi.N,INPUTVARS.ShiftAzi/pi);
			case 'ConstantSpacingIn'
				STRINGS.(fld{1}) = sprintf('Integrating to: %s (The unit in which the resulting bin-centers are equidistant)',INPUTVARS.ConstantSpacingIn);
			case 'center'
				fld
				STRINGS.(fld{1}) = sprintf('Detector center: (%g,%g) = (vertical,horizontal), i.e.: (rows,cols)',EXPERIMENT_INFO.center.y,EXPERIMENT_INFO.center.x);
		end
	end
	
	
	
	
	
	if INPUTVARS.PrintInfo
		fprintf('------- SETTINGS --------\n')
		fprintf('%s - Running: Indexing for unfolding:\n',datestr(now,13))
		linesToPrint = fields(STRINGS);
		for fld = linesToPrint.'
			if EXPERIMENT_INFO.manuallySet.(fld{1})
				fprintf('[X] %s\n',STRINGS.(fld{1}))
			else
				fprintf('[ ] %s\n',STRINGS.(fld{1}))
			end
		end
		fprintf('------- CORRECTIONS --------\n')
		fprintf([preString,' Mask: %-8s (Pct. masked out: %2.2f %%, Threshold: %g, if the percentage of masked-out-pixels (in a bin) exceeds %g pct., the entire bin is set to nan, if not, it is corrected for)\n'],trueFalseStrConv(INPUTVARS.doMaskCorrection),(1-nnz(mask)./numel(mask))*100,INPUTVARS.MaskCorrectionThreshold,INPUTVARS.MaskCorrectionThreshold*100)
		
	
	
	
		
		
		
		
		
		
		
		
		
		
		
		
		
		
		if INPUTVARS.doTiltCorrection
			if ~EXPERIMENT_INFO.tilt.rot && ~EXPERIMENT_INFO.tilt.delta
				INPUTVARS.doTiltCorrection = false;
				fprintf([preString,'Detector tilt: %-8s (due to: Tilt rotation: %g, Tilt delta: %g)\n'],trueFalseStrConv(INPUTVARS.doTiltCorrection),EXPERIMENT_INFO.tilt.rot,EXPERIMENT_INFO.tilt.delta)
			else
				fprintf([preString,'Detector tilt: %-8s (Tilt rotation: %g, Tilt delta: %g)\n'],trueFalseStrConv(INPUTVARS.doTiltCorrection),EXPERIMENT_INFO.tilt.rot,EXPERIMENT_INFO.tilt.delta)
			end
		else
			fprintf([preString,'Detector tilt: %-8s\n'],trueFalseStrConv(INPUTVARS.doTiltCorrection))
		end
		chosenCrystalStr = regexprep("" + INPUTVARS.PolarizationFactors(2) + " at phi = 90 deg.",{'1','2'},{'perfect (dynamic) crystal','imperfect (kinematic) crystal'});
		fprintf([preString,'Polarization: %-8s (Pol. factor: %g, n = %g i.e. %s)\n'],trueFalseStrConv(INPUTVARS.doPolarizationCorrection),INPUTVARS.PolarizationFactors(1),INPUTVARS.PolarizationFactors(2), chosenCrystalStr)
		fprintf([preString,'Lorentz: %-8s (Start of Lorentz correction, aka. the end of SAXS region: %g %s)\n'],trueFalseStrConv(INPUTVARS.doLorentzCorrection),INPUTVARS.LorentzCorrectionStartRadius,INPUTVARS.RadiusUnit)
		fprintf([preString,'Solid Angle: %-8s (should ONLY be ENABLED if constant pixel spacing was chosen)\n'],trueFalseStrConv(INPUTVARS.doSolidAngleCorrection))
		fprintf([preString,'Out-of-detector: %-8s (Compensate for incomplete Debye-Scherrer rings)\n'],trueFalseStrConv(INPUTVARS.doOutOfDetectorCorrection))
		fprintf([preString,'Normalization: %-8s\n'],INPUTVARS.NormalizationMethod)
		if INPUTVARS.Debugging; fprintf([preString,'Debugging MODE: %-8s\n'],trueFalseStrConv(INPUTVARS.Debugging));end
	end

	INPUTVARS.MATLABversionYear = str2double(regexp(version(),'(?<=R)\d{4}','match','once'));

	function ERRORFCN()
		if any(isnan(mask))
			error('Mask input contain NaNs, the input mask should preferably be a logical matrix containing 0/false (masked out) and 1/true (kept values).')
		end
		if all(mask == 0)
			error('Mask input only contain zeros/false, the input mask should preferably be a logical matrix containing 0/false (masked out) and 1/true (kept values).')
		end
		
		if isempty(INPUTVARS.Radius); INPUTVARS.Radius = calculateRadiusBoundaries(EXPERIMENT_INFO.center,EXPERIMENT_INFO.detector.distance,EXPERIMENT_INFO.detector.pixsize,size(mask),INPUTVARS.RadiusUnit); end
		Radius	= INPUTVARS.Radius;
		Azi	= INPUTVARS.Azi;
% 		scaling	= INPUTVARS.Scaling;
		if INPUTVARS.doMaskCorrection
			assert(~isempty(INPUTVARS.MaskCorrectionThreshold),"a non-empty 'MaskCorrectionThreshold' field is needed in the '%s'-struct, please provide this.",inputnames{3})
		end
		assert(NOinputs4indexing == 3,'Incorrect number of input arguments (%g was provided, but at least 3 are needed)',NOinputs4indexing)
		assert(isstruct(EXPERIMENT_INFO),'Incorrect inputtype for input no. 2, (input variable is named: "%s" in the function call), the type was "%s" but should be struct.',inputnames{2},class(EXPERIMENT_INFO))
		assert(isstruct(INTEGRATION_OPTIONS),'Incorrect inputtype for input no. 3, (input variable is named: "%s" in the function call), the type was "%s" but should be struct.',inputnames{2},class(INTEGRATION_OPTIONS))
		% CHECK EX STRUCT:
		if ~INPUTVARS.SuppressTiltCheck && INPUTVARS.doTiltCorrection
			if isfield(EXPERIMENT_INFO,'tilt')
				if isfield(EXPERIMENT_INFO.tilt,'delta') && isfield(EXPERIMENT_INFO.tilt,'rot')
					assert(0 <= EXPERIMENT_INFO.tilt.delta, 'The angle for in-plane rotation of detector coordinates (the EX.tilt.delta = %g) is not within 0 <= angle[deg.] <= 180, as it should be.',EXPERIMENT_INFO.tilt.delta)
				else
					error('EXPERIMENT_INFO.tilt struct is missing "delta" or "rot" field. Please either set name-pair value "SuppressTiltCheck" to true, or defile EXPERIMENT_INFO.tilt.delta and EXPERIMENT_INFO.tilt.rot.')
				end
			else
				error('EX struct is missing "tilt"-field. Please either set name-pair value "SuppressTiltCheck" to true, or defile EXPERIMENT_INFO.tilt.delta and EXPERIMENT_INFO.tilt.rot.')
			end
		end
		ErrorsFromMissingFields = 0;
		% CHECK Radius STRUCT:
		if ~all(isfield(Radius,{'N','min','max'}))
			requiredfields = {'min','max','N'};
			missingfields = requiredfields(~isfield(Radius,requiredfields));
			fprintf('"Radius"-struct is missing the following fields: ');
			for ii = 1:numel(missingfields)-1; fprintf('"%s", ',missingfields{ii});end;fprintf('"%s".\n',missingfields{end});
			ErrorsFromMissingFields = ErrorsFromMissingFields + numel(missingfields);
		end
		% CHECK Azi STRUCT:
		if ~all(isfield(Azi,{'N','min','max'}))
			requiredfields = {'min','max','N'};
			missingfields = requiredfields(~isfield(Azi,requiredfields));
			fprintf('"Azi"-struct is missing the following fields: ');
			for ii = 1:numel(missingfields)-1; fprintf('"%s", ',missingfields{ii});end;fprintf('"%s".\n',missingfields{end});
			ErrorsFromMissingFields = ErrorsFromMissingFields + numel(missingfields);
		end
		assert(ErrorsFromMissingFields == 0,'A total of %d field(s) where missing from the struct(s) indicated above.',ErrorsFromMissingFields);
		% If RadiusUnit is set to pixels and SAXSstop is default, then the default are recalculated into a radius in units of pixels.
		if strcmp(INPUTVARS.RadiusUnit,'pixels') && any(strcmp('LorentzCorrectionStartRadius',INPUTS.UsingDefaults))
			INPUTVARS.LorentzCorrectionStartRadius = tand(INPUTVARS.LorentzCorrectionStartRadius)*EXPERIMENT_INFO.detector.distance/EXPERIMENT_INFO.detector.pixsize;
		end
		if Radius.min > INPUTVARS.LorentzCorrectionStartRadius
			fprintf('ATTENTION: Radius.min < LorentzCorrectionStartRadius (in units of %s), i.e. (%g < %g). This means that the signal of the pixels in the range of %g <= distance < %g from center will NOT be Lorentz corrected, while %g <= distance < %g will.\n',...
				INPUTVARS.RadiusUnit,Radius.min,INPUTVARS.LorentzCorrectionStartRadius,Radius.min,INPUTVARS.LorentzCorrectionStartRadius, INPUTVARS.LorentzCorrectionStartRadius, Radius.max)
		end
		if ~INPUTVARS.doSolidAngleCorrection && strcmp(INPUTVARS.ConstantSpacingIn,'pixels')
			for NOwarnings = 1:3; fprintf("! N.B.: due to constant spacing set to pixels, the setting for doSolidAngleCorrection should be ENABLED (set to TRUE)!\n"); end
		end
	end
end
	

function fieldsInArray = getAllFieldsInArray(structure)
	arr = [];
	allFields = fields(structure)
	for field = allFields.'
		if isstruct(structure.(field))
			arr = [arr,getAllFieldsInArray(structure.(field))];
		else
			arr = [arr,structure.(field)];
		end
	end
end