function UnfoldedIM = integrate(UnfoldIndexing,IMvector)
%% Integration / unfolding of multiple images utilising calculations performed in matFAI.indexing(...) routine.
% ---------------- Various info ----------------
% OBS.: RESHAPE IMvector BEFORE INPUTING IT INTO THIS FUNCTION: 
% 
% IMvector = reshape(IM,[numel(IM(:,:,1)) size(IM,3)]);
% 
% The above also takes care of having more than one image in your IM matrix,
% thus integrating several images simultaneously!
% 
% Alternatively, but slower, and IM shall only contain one image:
% 
% IMvector = IM(:);
% 
%
% ---------------- UPDATE LOG ----------------
%
%   17th of January 2019
%       -   Reduced inputs from unfIntUnfolding(UnfoldIndexing,IMvector,RadiusN,AziN)
%           to unfIntUnfolding(UnfoldIndexing,IMvector), where RadiusN and AziN
%           are now found in UnfoldIndexing structure.
%
%   16th of January 2019
%       -   NANCORRECTION removed and incorporated in weights in transformation
%           matrix!
% ---------------------------------------------
      
%% Unfolding and integration
% Description of concept: Apply transformation matrix weighing each pixels
% (respectively into different (calculated) unfolded bins), and apply 
% correction (NaN) to compensate for "removed" nan-values, and reshape into 
% [NO. 2theta bins x NO. Azimuthal bins] dimensions

UnfoldedIM = reshape(UnfoldIndexing.TRANSMAT*IMvector,[UnfoldIndexing.RadiusN, UnfoldIndexing.AziN, size(IMvector,2)]);
end