%% Load all images in a h5 file and integrate them
clc
clearvars 
fclose all; 
startTime = tic;

Ims = h5read(fullfile('path','to','file.h5'),'/path/to/data');

%removing "hot pixels" (threshold depends on the experiment) 
Ims(1e3 < Ims) 	= 0;
Ims 		= reshape(Ims,[],size(Ims,3));
Ims 		= double(Ims);


%% Experiment description:
poniSettings = {'pixsize',75e-6};
poniFile = 'PathToFile.poni';
EX = MatFRAIA.subfunctions.PONI.readAndOrConvert(poniFile,poniSettings{:});

%% Integration settings
IntSettings.scaling	= 20; % The side of the square each pixel will be divided into. A higher number will produce more accurate data

% Azimuthal information
IntSettings.Azi.min	= 0; % Min azimuthal angle (in rad)
IntSettings.Azi.max	= 2*pi; % Max azimuthal angle (in rad)
IntSettings.Azi.N	  = 1;

% Radial information
IntSettings.Radius.min = 0; % Min radius (in degrees)
IntSettings.Radius.max = 30; % Max radius (in degrees)
IntSettings.Radius.N   = 1000; %numel(Radius.min:Radius.max); % Number of radial bins (2theta)
% If 1 pixel spacing is wanted then use: Radius.N = numel(Radius.min:Radius.max),
% if oversampeling is wanted multiply the before specified number with the
% wanted oversampeling

% MaskCorrectionThreshold is VERY mask (and Azi.N) specific, and thus needs
% to be tested for different experiments/masks/Azi.N's
% If the percentage of masked-out-pixels (in a bin) exceeds this value,
% the entire bin is set to nan, if not, it is corrected for
IntSettings.MaskCorrectionThreshold = 0.3;

IntSettings.RadiusUnit = 'degrees';

% Corrections
IntSettings.doLorentzCorrection = true;
IntSettings.doPolarizationCorrection = true;
IntSettings.doTiltCorrection = true;
IntSettings.doMaskCorrection =true;
IntSettings.doOutOfDetectorCorrection =true;

mask = ~logical(importdata(fullfile('path','To','Mask.tif')).');


	
%% Indexing and calculating integrated images
[IntegrationIndex, infoOut] = MatFRAIA.indexing(mask, EX, IntSettings);
	

IntegratedImage = MatFRAIA.integrate(IntegrationIndex,Ims);
